@@ -2,42 +2,20 @@
     commands/setinitialpincommand.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2009 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
 
 #include "setinitialpincommand.h"
-#include "command_p.h"
+#include "cardcommand_p.h"
 
-#include <dialogs/setinitialpindialog.h>
+#include "dialogs/setinitialpindialog.h"
 
-#include <smartcard/readerstatus.h>
+#include "smartcard/netkeycard.h"
+#include "smartcard/readerstatus.h"
 
 #include <KLocalizedString>
 
@@ -48,7 +26,7 @@ using namespace Kleo::Dialogs;
 using namespace Kleo::SmartCard;
 using namespace GpgME;
 
-class SetInitialPinCommand::Private : public Command::Private
+class SetInitialPinCommand::Private : public CardCommand::Private
 {
     friend class ::Kleo::Commands::SetInitialPinCommand;
     SetInitialPinCommand *q_func() const
@@ -56,13 +34,12 @@ class SetInitialPinCommand::Private : public Command::Private
         return static_cast<SetInitialPinCommand *>(q);
     }
 public:
-    explicit Private(SetInitialPinCommand *qq);
+    explicit Private(SetInitialPinCommand *qq, const std::string &serialNumber);
     ~Private();
 
 private:
     void init()
     {
-
     }
 
     void ensureDialogCreated() const
@@ -76,11 +53,6 @@ private:
         dlg->setAttribute(Qt::WA_DeleteOnClose);
         dlg->setWindowTitle(i18nc("@title:window", "Set Initial Pin"));
 
-        const std::vector<Card::PinState> pinStates = ReaderStatus::instance()->pinStates(0);
-
-        dlg->setNksPinPresent(pinStates.size() >= 1 && pinStates[0] != Card::NullPin);
-        dlg->setSigGPinPresent(pinStates.size() >= 3 && pinStates[2] != Card::NullPin);
-
         connect(dlg, SIGNAL(nksPinRequested()), q_func(), SLOT(slotNksPinRequested()));
         connect(dlg, SIGNAL(sigGPinRequested()), q_func(), SLOT(slotSigGPinRequested()));
         connect(dlg, SIGNAL(rejected()), q_func(), SLOT(slotDialogRejected()));
@@ -100,18 +72,26 @@ private:
     }
 
 private:
+    void setInitialPin(const char *pinRef, const char *resultSlot)
+    {
+        const auto nksCard = ReaderStatus::instance()->getCard<NetKeyCard>(serialNumber());
+        if (!nksCard) {
+            error(i18n("Failed to find the NetKey card with the serial number: %1", QString::fromStdString(serialNumber())));
+            return;
+        }
+
+        const QByteArray command = QByteArray("SCD PASSWD --nullpin ") + pinRef;
+        ReaderStatus::mutableInstance()->startSimpleTransaction(nksCard, command, dialog, resultSlot);
+    }
+
     void slotNksPinRequested()
     {
-        ReaderStatus::mutableInstance()
-        ->startSimpleTransaction("SCD PASSWD --nullpin PW1.CH",
-                                 dialog, "setNksPinSettingResult");
+        setInitialPin("PW1.CH", "setNksPinSettingResult");
     }
 
     void slotSigGPinRequested()
     {
-        ReaderStatus::mutableInstance()
-        ->startSimpleTransaction("SCD PASSWD --nullpin PW1.CH.SIG",
-                                 dialog, "setSigGPinSettingResult");
+        setInitialPin("PW1.CH.SIG", "setSigGPinSettingResult");
     }
 
     void slotDialogRejected()
@@ -144,17 +124,16 @@ const SetInitialPinCommand::Private *SetInitialPinCommand::d_func() const
 #define q q_func()
 #define d d_func()
 
-SetInitialPinCommand::Private::Private(SetInitialPinCommand *qq)
-    : Command::Private(qq, nullptr),
+SetInitialPinCommand::Private::Private(SetInitialPinCommand *qq, const std::string &serialNumber)
+    : CardCommand::Private(qq, serialNumber, nullptr),
       dialog()
 {
-
 }
 
 SetInitialPinCommand::Private::~Private() {}
 
-SetInitialPinCommand::SetInitialPinCommand()
-    : Command(new Private(this))
+SetInitialPinCommand::SetInitialPinCommand(const std::string &serialNumber)
+    : CardCommand(new Private(this, serialNumber))
 {
     d->init();
 }
@@ -169,6 +148,20 @@ QDialog *SetInitialPinCommand::dialog() const
 
 void SetInitialPinCommand::doStart()
 {
+    d->ensureDialogCreated();
+
+    const auto nksCard = ReaderStatus::instance()->getCard<NetKeyCard>(d->serialNumber());
+    if (!nksCard) {
+        d->error(i18n("Failed to find the NetKey card with the serial number: %1", QString::fromStdString(d->serialNumber())));
+        d->dialog->close();
+        finished();
+        return;
+    }
+
+    const std::vector<Card::PinState> pinStates = nksCard->pinStates();
+    d->dialog->setNksPinPresent(pinStates.size() >= 1 && pinStates[0] != Card::NullPin);
+    d->dialog->setSigGPinPresent(pinStates.size() >= 3 && pinStates[2] != Card::NullPin);
+
     d->ensureDialogVisible();
 }
 
