@@ -16,7 +16,7 @@
 
 #include <gpgme++/global.h>
 
-class QStringList;
+#include <QStringList>
 
 namespace Kleo
 {
