@@ -125,7 +125,6 @@ public:
         : q(qq),
           ui(q)
     {
-
     }
 
 private:
@@ -207,6 +206,10 @@ private:
             }
 
             std::copy(lines.begin(), lines.end(), std::back_inserter(lineList));
+
+            QObject::connect(nameLE, SIGNAL(textChanged(QString)), qq, SLOT(slotUserIDChanged()));
+            QObject::connect(emailLE, SIGNAL(textChanged(QString)), qq, SLOT(slotUserIDChanged()));
+            QObject::connect(commentLE, SIGNAL(textChanged(QString)), qq, SLOT(slotUserIDChanged()));
         }
 
         QPushButton *okPB() const
@@ -219,7 +222,8 @@ private:
 AddUserIDDialog::AddUserIDDialog(QWidget *p)
     : QDialog(p), d(new Private(this))
 {
-
+    // explicitly trigger an update after setup is complete
+    d->slotUserIDChanged();
 }
 
 AddUserIDDialog::~AddUserIDDialog() {}
@@ -312,7 +316,6 @@ bool AddUserIDDialog::Private::isComplete() const
 
 void AddUserIDDialog::Private::slotUserIDChanged()
 {
-
     ui.okPB()->setEnabled(isComplete());
 
     const QString name = q->name();
